@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Muldis::D; # package
-    use version 0.74; our $VERSION = qv('0.59.1');
+    use version 0.74; our $VERSION = qv('0.60.0');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Muldis::D
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.59.1.
+This document is Muldis::D version 0.60.0.
 
 =head1 PREFACE
 
@@ -42,9 +42,9 @@ L<Muldis::D::Dialect::HDMD_Perl6_Tiny>,
 L<Muldis::D::Dialect::HDMD_Perl5_Tiny>, L<Muldis::D::Conventions>,
 L<Muldis::D::Ext::Ordered>, L<Muldis::D::Ext::Integer>,
 L<Muldis::D::Ext::Blob>, L<Muldis::D::Ext::Text>,
-L<Muldis::D::Ext::QTuple>, L<Muldis::D::Ext::QRelation>,
-L<Muldis::D::Ext::QSet>, L<Muldis::D::Ext::QArray>,
-L<Muldis::D::Ext::QBag>, L<Muldis::D::Ext::Rational>,
+L<Muldis::D::Ext::Rational>, L<Muldis::D::Ext::QTuple>,
+L<Muldis::D::Ext::QRelation>, L<Muldis::D::Ext::QSet>,
+L<Muldis::D::Ext::QArray>, L<Muldis::D::Ext::QBag>,
 L<Muldis::D::Ext::Temporal>, L<Muldis::D::Ext::Spatial>.
 
 =head1 DESCRIPTION
@@ -58,9 +58,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:'http://muldis.com':'0.59.1'>.  It is the official/original (not
+C<Muldis_D:'http://muldis.com':'0.60.0'>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<http://muldis.com>), version C<0.59.1> (this number
+Darren Duncan (C<http://muldis.com>), version C<0.60.0> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
